// SPDX-FileCopyrightText: © 2025 Allegro DVT <github-ip@allegrodvt.com>
// SPDX-License-Identifier: MIT

#pragma once

#include "ROIMngr.hpp"
#include "module_enums.hpp"

AL_ERoiQuality ConvertModuleToSoftQualityByPreset(QualityType const& quality);
